# Installation

## Stable release

To install ss-fha, run this command in your terminal:

```sh
uv add ss-fha
```

Or if you prefer to use `pip`:

```sh
pip install ss-fha
```

## From source

The source files for ss-fha can be downloaded from the [Github repo](https://github.com/lassiterdc/ss_fha).

You can either clone the public repository:

```sh
git clone https://github.com/lassiterdc/ss_fha
```

Or download the [tarball](https://github.com/lassiterdc/ss_fha/tarball/main):

```sh
curl -OJL https://github.com/lassiterdc/ss_fha/tarball/main
```

Once you have a copy of the source, you can install it with:

```sh
cd ss_fha
uv sync
```
